@@ -3,7 +3,7 @@
 namespace PhpParser;
 
 abstract class CodeTestAbstract extends \PHPUnit\Framework\TestCase {
-    protected function getTests($directory, $fileExtension, $chunksPerTest = 2) {
+    protected static function getTests($directory, $fileExtension, $chunksPerTest = 2) {
         $parser = new CodeTestParser();
         $allTests = [];
         foreach (filesInDir($directory, $fileExtension) as $fileName => $fileContents) {
