@@ -3,7 +3,7 @@
 namespace PhpParser\Node;
 
 class NameTest extends \PHPUnit\Framework\TestCase {
-    public function testConstruct() {
+    public function testConstruct(): void {
         $name = new Name(['foo', 'bar']);
         $this->assertSame('foo\bar', $name->name);
 
@@ -14,7 +14,7 @@ class NameTest extends \PHPUnit\Framework\TestCase {
         $this->assertSame('foo\bar', $name->name);
     }
 
-    public function testGet() {
+    public function testGet(): void {
         $name = new Name('foo');
         $this->assertSame('foo', $name->getFirst());
         $this->assertSame('foo', $name->getLast());
@@ -26,7 +26,7 @@ class NameTest extends \PHPUnit\Framework\TestCase {
         $this->assertSame(['foo', 'bar'], $name->getParts());
     }
 
-    public function testToString() {
+    public function testToString(): void {
         $name = new Name('Foo\Bar');
 
         $this->assertSame('Foo\Bar', (string) $name);
@@ -34,7 +34,7 @@ class NameTest extends \PHPUnit\Framework\TestCase {
         $this->assertSame('foo\bar', $name->toLowerString());
     }
 
-    public function testSlice() {
+    public function testSlice(): void {
         $name = new Name('foo\bar\baz');
         $this->assertEquals(new Name('foo\bar\baz'), $name->slice(0));
         $this->assertEquals(new Name('bar\baz'), $name->slice(1));
@@ -50,37 +50,37 @@ class NameTest extends \PHPUnit\Framework\TestCase {
         $this->assertNull($name->slice(-2, -2));
     }
 
-    public function testSliceOffsetTooLarge() {
+    public function testSliceOffsetTooLarge(): void {
         $this->expectException(\OutOfBoundsException::class);
         $this->expectExceptionMessage('Offset 4 is out of bounds');
         (new Name('foo\bar\baz'))->slice(4);
     }
 
-    public function testSliceOffsetTooSmall() {
+    public function testSliceOffsetTooSmall(): void {
         $this->expectException(\OutOfBoundsException::class);
         $this->expectExceptionMessage('Offset -4 is out of bounds');
         (new Name('foo\bar\baz'))->slice(-4);
     }
 
-    public function testSliceLengthTooLarge() {
+    public function testSliceLengthTooLarge(): void {
         $this->expectException(\OutOfBoundsException::class);
         $this->expectExceptionMessage('Length 4 is out of bounds');
         (new Name('foo\bar\baz'))->slice(0, 4);
     }
 
-    public function testSliceLengthTooSmall() {
+    public function testSliceLengthTooSmall(): void {
         $this->expectException(\OutOfBoundsException::class);
         $this->expectExceptionMessage('Length -4 is out of bounds');
         (new Name('foo\bar\baz'))->slice(0, -4);
     }
 
-    public function testSliceLengthTooLargeWithOffset() {
+    public function testSliceLengthTooLargeWithOffset(): void {
         $this->expectException(\OutOfBoundsException::class);
         $this->expectExceptionMessage('Length 3 is out of bounds');
         (new Name('foo\bar\baz'))->slice(1, 3);
     }
 
-    public function testConcat() {
+    public function testConcat(): void {
         $this->assertEquals(new Name('foo\bar\baz'), Name::concat('foo', 'bar\baz'));
         $this->assertEquals(
             new Name\FullyQualified('foo\bar'),
@@ -98,7 +98,7 @@ class NameTest extends \PHPUnit\Framework\TestCase {
         $this->assertNull(Name::concat(null, null));
     }
 
-    public function testNameTypes() {
+    public function testNameTypes(): void {
         $name = new Name('foo');
         $this->assertTrue($name->isUnqualified());
         $this->assertFalse($name->isQualified());
@@ -128,31 +128,31 @@ class NameTest extends \PHPUnit\Framework\TestCase {
         $this->assertSame('namespace\foo', $name->toCodeString());
     }
 
-    public function testInvalidArg() {
+    public function testInvalidArg(): void {
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('Expected string, array of parts or Name instance');
         Name::concat('foo', new \stdClass());
     }
 
-    public function testInvalidEmptyString() {
+    public function testInvalidEmptyString(): void {
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('Name cannot be empty');
         new Name('');
     }
 
-    public function testInvalidEmptyArray() {
+    public function testInvalidEmptyArray(): void {
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('Name cannot be empty');
         new Name([]);
     }
 
     /** @dataProvider provideTestIsSpecialClassName */
-    public function testIsSpecialClassName($name, $expected) {
+    public function testIsSpecialClassName($name, $expected): void {
         $name = new Name($name);
         $this->assertSame($expected, $name->isSpecialClassName());
     }
 
-    public function provideTestIsSpecialClassName() {
+    public static function provideTestIsSpecialClassName() {
         return [
             ['self', true],
             ['PARENT', true],
